@@ -90,12 +90,11 @@ def get_mapper(mixed):
         ]
         if len(mappers) > 1:
             raise ValueError(
-                "Multiple mappers found for table '%s'."
-                % mixed.name
+                "Multiple mappers found for table '%s'." % mixed.name
             )
         elif not mappers:
             raise ValueError(
-                "Could not get mapper for table '%s'."
+                "Could not get mapper for table '%s'." % mixed.name
             )
         else:
             return mappers[0]
@@ -496,7 +495,7 @@ def get_descriptor(entity, attr):
                     # but not in parent class.
                     return getattr(prop.parent.class_, attr)
             else:
-                # Handle synonyms, relationship proeprties and hybrid
+                # Handle synonyms, relationship properties and hybrid
                 # properties
                 try:
                     return getattr(entity, attr)
@@ -508,10 +507,11 @@ def get_all_descriptors(expr):
     insp = sa.inspect(expr)
     polymorphic_mappers = get_polymorphic_mappers(insp)
     if polymorphic_mappers:
-
-        attrs = {}
+        attrs = dict(get_mapper(expr).all_orm_descriptors)
         for submapper in polymorphic_mappers:
-            attrs.update(submapper.all_orm_descriptors)
+            for key, descriptor in submapper.all_orm_descriptors.items():
+                if key not in attrs:
+                    attrs[key] = descriptor
         return attrs
     return get_mapper(expr).all_orm_descriptors
 
